/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.ws.addr_responses;
import jakarta.jws.WebService;
import jakarta.xml.ws.soap.Addressing;
import jakarta.xml.ws.soap.AddressingFeature.Responses;


@WebService(name = "Hello", serviceName = "HelloService", portName = "HelloPort",
            targetNamespace = "http://cxf.apache.org/systest/wsa/responses",
            endpointInterface = "org.apache.cxf.systest.ws.addr_responses.Hello")
@Addressing(responses = Responses.NON_ANONYMOUS)
public class HelloImpl implements Hello {
    public String sayHi(String arg0) {
        return "get" + arg0;
    }

}
